@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """
 Implement a PGN reader/writer.
 
@@ -389,7 +390,7 @@ class PGNGame:
         """
         if self._isValidTagName(name) is False:
             raise Error('%s is an invalid tag name' % str(name))
-        
+
         # If no value delete
         if value is None:
             # If is a STR tag throw an exception
@@ -482,8 +483,6 @@ class PGNGame:
 class PGN:
     """
     """
-    
-    __games = None
 
     def __init__(self, fileName = None, maxGames = None):
         """Create a PGN reader/writer.
@@ -557,7 +556,7 @@ class PGN:
                 p.parseLine(line)
             p.complete()
         except Error, e:
-            raise Error('Error on line %d: %s' % (lineNumber, e.args[0]))
+            raise Error('Error on line %d: %s' % (lineNumber, str(e)))
 
         # Must be at least one game in the PGN file
         self.__games = p.games
