@@ -36,6 +36,8 @@
 #include <libgames-support/games-runtime.h>
 #include <libgames-support/games-scores.h>
 #include <libgames-support/games-stock.h>
+#include <libgames-support/games-pause-action.h>
+#include <libgames-support/games-fullscreen-action.h>
 
 #include "main.h"
 #include "properties.h"
@@ -101,8 +103,6 @@ gint keyboard_id = 0;
 gint add_bonus_id = 0;
 gint restart_id = 0;
 
-gint paused = 0;
-
 gint current_level;
 
 static gint add_bonus_cb (gpointer data);
@@ -114,13 +114,11 @@ static void hide_logo (void);
 static GtkAction *new_game_action;
 static GtkAction *new_network_action;
 static GtkAction *player_list_action;
-static GtkAction *pause_action;
-static GtkAction *resume_action;
+GtkAction *pause_action;
 static GtkAction *end_game_action;
 static GtkAction *preferences_action;
 static GtkAction *scores_action;
 static GtkAction *fullscreen_action;
-static GtkAction *leave_fullscreen_action;
 
 static ClutterActor *logo;
 
@@ -130,26 +128,6 @@ hide_cursor (void)
   clutter_stage_hide_cursor (CLUTTER_STAGE (stage));
 }
 
-static void
-set_fullscreen_actions (gboolean is_fullscreen)
-{
-  gtk_action_set_sensitive (leave_fullscreen_action, is_fullscreen);
-  gtk_action_set_visible (leave_fullscreen_action, is_fullscreen);
-
-  gtk_action_set_sensitive (fullscreen_action, !is_fullscreen);
-  gtk_action_set_visible (fullscreen_action, !is_fullscreen);
-}
-
-static void
-fullscreen_cb (GtkAction * action)
-{
-  if (action == fullscreen_action) {
-    gtk_window_fullscreen (GTK_WINDOW (window));
-  } else {
-    gtk_window_unfullscreen (GTK_WINDOW (window));
-  }
-}
-
 static void
 network_gui_update (void)
 {
@@ -167,18 +145,6 @@ network_gui_update (void)
 #endif
 }
 
-static gboolean
-window_state_cb (GtkWidget * widget, GdkEventWindowState * event)
-{
-  /* Handle fullscreen, in case something else takes us to/from fullscreen. */
-  if (event->changed_mask & GDK_WINDOW_STATE_FULLSCREEN)
-    set_fullscreen_actions (event->new_window_state
-                            & GDK_WINDOW_STATE_FULLSCREEN);
-
-  return FALSE;
-}
-
-
 static void
 show_cursor (void)
 {
@@ -188,7 +154,7 @@ show_cursor (void)
 gint
 game_running (void)
 {
-  return (main_id || dummy_id || restart_id || paused);
+  return (main_id || dummy_id || restart_id || games_pause_action_get_is_paused (GAMES_PAUSE_ACTION (pause_action)));
 }
 
 static void
@@ -333,7 +299,7 @@ network_loop (gpointer data)
 static gboolean
 new_game_2_cb (GtkWidget * widget, gpointer data)
 {
-  if (!paused) {
+  if (!games_pause_action_get_is_paused (GAMES_PAUSE_ACTION (pause_action))) {
     if (!keyboard_id)
       keyboard_id = g_signal_connect (G_OBJECT (stage),
                                       "key-press-event",
@@ -401,9 +367,7 @@ new_game (void)
     gnibbles_worm_show (worms[i]);
   }
 
-  paused = 0;
-  gtk_action_set_visible (pause_action, !paused);
-  gtk_action_set_visible (resume_action, paused);
+  games_pause_action_set_is_paused (GAMES_PAUSE_ACTION (pause_action), FALSE);
   gtk_action_set_visible (player_list_action, ggz_network_mode);
 
   if (restart_id) {
@@ -432,15 +396,11 @@ new_game_cb (GtkAction * action, gpointer data)
   new_game ();
 }
 
-gboolean
+static void
 pause_game_cb (GtkAction * action, gpointer data)
 {
-  if (paused) {
-    paused = 0;
-    dummy_id = g_timeout_add (500, (GSourceFunc) new_game_2_cb, NULL);
-  } else {
+  if (games_pause_action_get_is_paused (GAMES_PAUSE_ACTION (action))) {
     if (main_id || restart_id || dummy_id) {
-      paused = 1;
       if (main_id) {
         g_source_remove (main_id);
         main_id = 0;
@@ -455,13 +415,9 @@ pause_game_cb (GtkAction * action, gpointer data)
       }
     }
   }
-
-  gtk_action_set_sensitive (pause_action, !paused);
-  gtk_action_set_sensitive (resume_action, paused);
-  gtk_action_set_visible (pause_action, !paused);
-  gtk_action_set_visible (resume_action, paused);
-
-  return TRUE;
+  else {
+    dummy_id = g_timeout_add (500, (GSourceFunc) new_game_2_cb, NULL);
+  }
 }
 
 static void
@@ -502,14 +458,12 @@ end_game (gboolean show_splash)
     render_logo ();
     gtk_action_set_sensitive (new_network_action, TRUE);
     gtk_action_set_sensitive (pause_action, FALSE);
-    gtk_action_set_sensitive (resume_action, FALSE);
     gtk_action_set_sensitive (end_game_action, FALSE);
     gtk_action_set_sensitive (preferences_action, TRUE);
   }
 
   network_gui_update ();
-  paused = 0;
-
+  games_pause_action_set_is_paused (GAMES_PAUSE_ACTION (pause_action), FALSE);
 }
 
 static gboolean
@@ -749,19 +703,11 @@ static const GtkActionEntry action_entry[] = {
 #endif
   {"PlayerList", GAMES_STOCK_PLAYER_LIST, NULL, NULL, NULL,
    G_CALLBACK (on_player_list)},
-  {"Pause", GAMES_STOCK_PAUSE_GAME, NULL, NULL, NULL,
-   G_CALLBACK (pause_game_cb)},
-  {"Resume", GAMES_STOCK_RESUME_GAME, NULL, NULL, NULL,
-   G_CALLBACK (pause_game_cb)},
   {"EndGame", GAMES_STOCK_END_GAME, NULL, NULL, NULL,
    G_CALLBACK (end_game_cb)},
   {"Scores", GAMES_STOCK_SCORES, NULL, NULL, NULL,
    G_CALLBACK (show_scores_cb)},
   {"Quit", GTK_STOCK_QUIT, NULL, NULL, NULL, G_CALLBACK (quit_cb)},
-  {"Fullscreen", GAMES_STOCK_FULLSCREEN, NULL, NULL, NULL,
-   G_CALLBACK (fullscreen_cb)},
-  {"LeaveFullscreen", GAMES_STOCK_LEAVE_FULLSCREEN, NULL, NULL, NULL,
-   G_CALLBACK (fullscreen_cb)},
   {"Preferences", GTK_STOCK_PREFERENCES, NULL, NULL, NULL,
    G_CALLBACK (gnibbles_preferences_cb)},
   {"Contents", GAMES_STOCK_CONTENTS, NULL, NULL, NULL, G_CALLBACK (help_cb)},
@@ -778,7 +724,6 @@ static const char ui_description[] =
   "      <menuitem action='EndGame'/>"
   "      <separator/>"
   "      <menuitem action='Pause'/>"
-  "      <menuitem action='Resume'/>"
   "      <separator/>"
   "      <menuitem action='Scores'/>"
   "      <separator/>"
@@ -786,7 +731,6 @@ static const char ui_description[] =
   "    </menu>"
   "    <menu action='ViewMenu'>"
   "      <menuitem action='Fullscreen'/>"
-  "      <menuitem action='LeaveFullscreen'/>"
   "    </menu>"
   "    <menu action='SettingsMenu'>"
   "      <menuitem action='Preferences'/>"
@@ -815,15 +759,14 @@ create_menus (GtkUIManager * ui_manager)
   new_game_action = gtk_action_group_get_action (action_group, "NewGame");
   scores_action = gtk_action_group_get_action (action_group, "Scores");
   end_game_action = gtk_action_group_get_action (action_group, "EndGame");
-  pause_action = gtk_action_group_get_action (action_group, "Pause");
-  resume_action = gtk_action_group_get_action (action_group, "Resume");
+  pause_action = GTK_ACTION (games_pause_action_new ("Pause"));
+  g_signal_connect (G_OBJECT (pause_action), "state-changed", G_CALLBACK (pause_game_cb), NULL);
+  gtk_action_group_add_action_with_accel (action_group, pause_action, NULL);
 
   preferences_action = gtk_action_group_get_action (action_group,
                                                     "Preferences");
-  fullscreen_action = gtk_action_group_get_action (action_group,
-                                                   "Fullscreen");
-  leave_fullscreen_action = gtk_action_group_get_action (action_group,
-                                                         "LeaveFullscreen");
+  fullscreen_action = GTK_ACTION (games_fullscreen_action_new ("Fullscreen", GTK_WINDOW(window)));
+  gtk_action_group_add_action_with_accel (action_group, fullscreen_action, NULL);
   new_network_action = gtk_action_group_get_action (action_group,
                                                     "NewNetworkGame");
 #ifndef GGZ_CLIENT
@@ -867,8 +810,6 @@ setup_window (void)
                     G_CALLBACK (gtk_main_quit), NULL);
   g_signal_connect (G_OBJECT (window), "delete_event",
                     G_CALLBACK (delete_cb), NULL);
-  g_signal_connect (G_OBJECT (window), "window_state_event",
-                    G_CALLBACK (window_state_cb), NULL);
 
   gtk_widget_realize (window);
 
@@ -877,9 +818,9 @@ setup_window (void)
   games_stock_init ();
   ui_manager = gtk_ui_manager_new ();
   create_menus (ui_manager);
-  set_fullscreen_actions (FALSE);
   notebook = gtk_notebook_new ();
   gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
+  gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);
 
   accel_group = gtk_ui_manager_get_accel_group (ui_manager);
   gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
@@ -1106,9 +1047,7 @@ main (int argc, char **argv)
 #endif
 
   gtk_action_set_sensitive (pause_action, FALSE);
-  gtk_action_set_sensitive (resume_action, FALSE);
   gtk_action_set_sensitive (end_game_action, FALSE);
-  gtk_action_set_visible (resume_action, paused);
   gtk_action_set_visible (new_game_action, !ggz_network_mode);
   gtk_action_set_visible (player_list_action, ggz_network_mode);
 
