@@ -49,7 +49,12 @@ void games_preimage_set_font_options (GamesPreimage * preimage,
                                       const cairo_font_options_t *font_options);
 
 GdkPixbuf *games_preimage_render (GamesPreimage * preimage,
-                                  gint width, gint height);
+                                  gint width,
+                                  gint height);
+void games_preimage_render_cairo (GamesPreimage * preimage,
+                                  cairo_t *cr,
+                                  gint width,
+                                  gint height);
 
 GdkPixbuf *games_preimage_render_sub (GamesPreimage * preimage,
                                       const char *node,
@@ -59,6 +64,16 @@ GdkPixbuf *games_preimage_render_sub (GamesPreimage * preimage,
                                       double yoffset,
                                       double xzoom, double yzoom);
 
+void games_preimage_render_cairo_sub (GamesPreimage * preimage,
+                                      cairo_t *cr,
+                                      const char *node,
+                                      int width,
+                                      int height,
+                                      double xoffset,
+                                      double yoffset,
+                                      double xzoom,
+                                      double yzoom);
+
 gboolean games_preimage_is_scalable (GamesPreimage * preimage);
 
 gint games_preimage_get_width (GamesPreimage * preimage);
